__author__ = 'cmoravec'
import restclient
import json

class BitlyError(Exception):
    """Generic Bitly error."""
    pass


class Connection():
    """Class that represents a connection to the bitly api."""
    access_token=""
    _baseUrl=""
    def __init__(self,access_token):
        """Creates a connection object with the specified access_token.  This token should come from an oauth2 process."""
        self.access_token = access_token
        self._baseUrl = "https://api-ssl.bitly.com/v3/"

    def _fullUrl(self,suffix):
        """combines the self._baseUrl with the suffix, or action part of the url to make a complete url."""
        return self._baseUrl+suffix

    def _checkStatus(self,results):
        """Checks the status of a return, and raises Exceptions as appropriate."""
        try:
            if results.has_key("status_code"):
                if results["status_code"] == 200:
                    return
                else:
                    raise BitlyError("Status Code is not 200 (%s) (%s)"%(str(results["status_code"]),str(results["status_txt"])))
            else:
                raise BitlyError("No status code found.")
        except Exception as e:
            raise e


    def link_countries(self, link):
        """Find any countries that have clicked this link"""
        url = self._fullUrl("link/countries")
        params={"access_token":self.access_token,"link":link}
        result = restclient.GET(url,params)
        result = json.JSONDecoder().decode(result)
        self._checkStatus(result)
        returnData = []
        for item in result["data"]["countries"]:
            returnData.append(str(item["country"]).lower())
        return returnData

    def link_locations(self, link):
        """Find the current locations for the specified link"""
        url = self._fullUrl("link/location")
        params={"access_token":self.access_token,"link":link}
        result = restclient.GET(url,params)
        result = json.JSONDecoder().decode(result)
        self._checkStatus(result)
        return result["data"]["locations"]

    def link_history(self):
        """List the current logged-in user's link history"""
        url = self._fullUrl("user/link_history")
        params={"access_token":self.access_token}
        result = restclient.GET(url,params)
        result = json.JSONDecoder().decode(result)
        self._checkStatus(result)
        return result["data"]["link_history"]

    def realtime_bursting_phrases(self):
        """Lists the current realtime burst phrases."""
        url = self._fullUrl("realtime/bursting_phrases")
        params={"access_token":self.access_token}
        result = restclient.GET(url,params)
        result = json.JSONDecoder().decode(result)
        self._checkStatus(result)
        return result["data"]["phrases"]

    def realtime_hot_phrases(self):
        """Lists the current realtime hot phrases."""
        url = self._fullUrl("realtime/hot_phrases")
        params={"access_token":self.access_token}
        result = restclient.GET(url,params)
        result = json.JSONDecoder().decode(result)
        self._checkStatus(result)
        return result["data"]["phrases"]


def main():
    bit = Connection("<your api key here>")
    print bit.realtime_hot_phrases()
    print bit.link_history()
    print bit.realtime_bursting_phrases()

    print bit.link_locations("http://bit.ly/12LIn7D")

if __name__ == '__main__':
    main()